@@ -3,7 +3,7 @@ use base qw(Finance::LocalBitcoins::API::Request);
 use strict;
 
 use constant URL          => 'https://localbitcoins.com/bitcoincharts/%s/trades.json';
-#use constant ATTRIBUTES   => qw(currency);
+use constant ATTRIBUTES   => qw(since);
 use constant REQUEST_TYPE => 'GET';
 use constant IS_PRIVATE   => 0;
 
@@ -15,9 +15,10 @@ sub init {
 }
 
 sub currency         { my $self = shift; $self->get_set(@_) }
+sub since            { my $self = shift; $self->get_set(@_) }
 sub url              { sprintf URL, shift->currency }
 sub is_ready_to_send { defined shift->currency }
-#sub attributes       { ATTRIBUTES   }
+sub attributes       { ATTRIBUTES   }
 sub request_type     { REQUEST_TYPE }
 sub is_private       { IS_PRIVATE   }
 
